import { unwatchPageVisibility, watchPageVisibility } from '@spark/utils';
import { hideWaiting, showPanel, showToast, showWaiting } from "../../module/ctrls";
import PanelCtrl from '../../module/ctrls/panelCtrl';
import { Scene } from "../../module/views/Scene";
import centerTextField from '../common/centerTextField';
import getObject, { getObjects } from '../common/getObject';
import getQueryParams from '../common/getQueryParams';
import Marquee from '../common/Marquee';
import { ProgressBarS } from '../common/ProgressBarS';
import { hideShareMask, showShareMask } from '../common/ShareMask';
import { getStageHeight, getStageOffset } from '../common/stage';
import { MAX_MONEY, MONEY_PERCENT } from '../datas';
import { DrawPanel } from '../panels/draw';
import { RulePanel } from '../panels/rule';
import { ShareFailPanel } from '../panels/share_fail';
import { ShareSuccessPanel } from '../panels/share_success';
import updateShareFunc from '../share';
import { getPxTokenSave, getWebData, sendWebNet, WebNetName } from '../WebNet';
export class IndexScene extends Scene {

    updateIndexUI({ experienceAmount, yesterdayIncome, sumIncome, sevenDayAnnualization, assistFriendNum, otherExperienceAmount,canWithdraw }) {
        getObject(this, 'index_experienceAmountTips').text = experienceAmount || "0";
        getObject(this, 'index_sumIncomeTips').text = sumIncome || '0';
        getObject(this, 'index_sevenDayAnnualizationTips').text = sevenDayAnnualization;
        getObject(this, 'index_yesterdayIncomeTips').text = `昨日收益：${yesterdayIncome || '0'}元`;
        getObject(this, 'index_invitePercentTips').text = `${experienceAmount}/1000000`;
        getObject(this, 'index_inviteTips').text = `已有${assistFriendNum}位好友助力，体验金增加${otherExperienceAmount}元`;

        getObject(this, 'index_drawGrayBtn').visible = !canWithdraw;
        getObject(this, 'index_drawBtn').visible = canWithdraw;

        const index_experienceAmountTips2 = getObject(this, 'index_experienceAmountTips2');
        const index_experienceAmountTips = getObject(this, 'index_experienceAmountTips');
        index_experienceAmountTips2.x = 375 + experienceAmount.toString().length * 18;
        // const w = index_experienceAmountTips2.textWidth + index_experienceAmountTips.textWidth;
        // index_experienceAmountTips.x = (750 - w) / 2;
        // index_experienceAmountTips2.x = index_experienceAmountTips.x + index_experienceAmountTips.textWidth;

        let percent = MONEY_PERCENT;
        if (experienceAmount / MAX_MONEY > percent) {
            percent = experienceAmount / MAX_MONEY;
        }
        const progressBar = new ProgressBarS(getObject(this, 'index_progress'));
        progressBar.value = percent;

        const __tmp__ = { a: 0 };
        FYGE.Tween.get(__tmp__, {
            loop: false, onChange: (param) => {
                index_experienceAmountTips.text = Math.ceil(experienceAmount * __tmp__.a) + '';
                progressBar.value =percent*__tmp__.a;
            }
        }).to({ a: 1 }, 700)
    }

    onclick_index_inviteBtn() {
        showShareMask();
    }
    onclick_index_drawBtn() {
        const { canWithdraw } = getWebData(WebNetName.myWallet).data;
        if (canWithdraw) {
            showWaiting();
            getPxTokenSave().then(token => {
                sendWebNet(WebNetName.withDraw, { token: token }).then(res => {
                    hideWaiting();
                    if (res.success)
                        showPanel(DrawPanel, res.data);
                });
            })
        } else {
            showToast('收益未满7天，不能提现哦～')
        }


    }

    page: FYGE.ScrollPage;
    initUi() {
        super.initUi();

        const page = this.page = new FYGE.ScrollPage(750, getStageHeight(), 1624, true, true);
        this.addChild(page);
        page.y = getStageOffset();

        this.page.view.addChild(getObject(this, 'index_wrapper'));

        getObject(this, 'index_drawGrayBtn').visible = false;
        getObject(this, 'index_drawBtn').visible = false;

        centerTextField(getObjects(this, [
            'index_yesterdayIncomeTips',
            'index_invitePercentTips',
            'index_experienceAmountTips',
            'index_inviteTips'
        ]));

        centerTextField(getObject(this, 'index_sumIncomeTips'), 0, -144 + 5);
        centerTextField(getObject(this, 'index_sevenDayAnnualizationTips'), 0, 140);
    }

    async start(data) {
        super.start(data);
        data = data || {};
        const { action, from } = data;
        console.log('IndexScene', 'from=', from, 'action=', action);
        if (action == 'showSharePanel') {
            this.showSharePanel();
        }
        // setTimeout(() => {
        //     showPanel(DrawPanel)
        // }, 1000);

        sendWebNet(WebNetName.carouselInfo).then(res => {


            const template = '{phone}邀请1位好友，获得了{amount}体验金';
            const datas = res.data.map(item => {
                let str = template.replace('{phone}', item.nickname);
                str = str.replace('{amount}', item.amount);
                return str
            });
            const q = getObject(this, 'index_wrapper').addChild(new Marquee(datas));
            q.x = 135; q.y = 191;
            window['q'] = q;
        });

        getPxTokenSave().then(token => {
            sendWebNet(WebNetName.myWallet, { token: token }).then(myWalletResult => {
                console.log('获取钱包信息');
                this.updateIndexUI(myWalletResult.data);
                getPxTokenSave().then(token => {
                    sendWebNet(WebNetName.createItem, { token: token }).then(createItemResult => {
                        updateShareFunc('inIndexScene', createItemResult.data)
                    });
                })

            });
        })
    }

    async showSharePanel() {
        getPxTokenSave().then(token => {
            sendWebNet(WebNetName.myWallet, { token: token }).then(myWalletResult => {
                if (myWalletResult.data.experienceAmount >= myWalletResult.data.maxExperienceAmount) {
                    showPanel(ShareFailPanel);
                } else {
                    showPanel(ShareSuccessPanel);
                }
            });
        })
    }

    onPageVisibilityChange = async (visible) => {
        if (getQueryParams().disablewatch == 1) { console.log('disable watch'); return; }
        console.log('页面visible', visible);
        if (!visible) return;
        const current = PanelCtrl.instance.current;
        if (current)
            console.log('有弹窗就不重复弹分享弹窗了');
        if (visible && !current) {
            hideShareMask();
            this.showSharePanel();
        }
    }

    onclick_index_ruleBtn() {
        showPanel(RulePanel);
    }

    initEvents() {
        super.initEvents();
        watchPageVisibility(this.onPageVisibilityChange);
        getObject(this, 'index_drawBtn').addEventListener(FYGE.MouseEvent.CLICK, this.onclick_index_drawBtn, this)
        getObject(this, 'index_drawGrayBtn').addEventListener(FYGE.MouseEvent.CLICK, this.onclick_index_drawBtn, this)
        getObject(this, 'index_rulebtn').addEventListener(FYGE.MouseEvent.CLICK, this.onclick_index_ruleBtn, this)
        getObject(this, 'index_inviteBtn').addEventListener(FYGE.MouseEvent.CLICK, this.onclick_index_inviteBtn, this)
    }

    removeEvents() {
        super.removeEvents();
        unwatchPageVisibility(this.onPageVisibilityChange)
        getObject(this, 'index_inviteBtn').removeEventListener(FYGE.MouseEvent.CLICK, this.onclick_index_inviteBtn, this)
        getObject(this, 'index_drawBtn').removeEventListener(FYGE.MouseEvent.CLICK, this.onclick_index_drawBtn, this)
        getObject(this, 'index_drawGrayBtn').removeEventListener(FYGE.MouseEvent.CLICK, this.onclick_index_drawBtn, this)
        getObject(this, 'index_rulebtn').removeEventListener(FYGE.MouseEvent.CLICK, this.onclick_index_ruleBtn, this)
    }

    get groupNames() { return ["index"] }
    get skinName() { return "index" }
}
