import { unwatchPageVisibility, watchPageVisibility } from "@spark/utils";
import { changeScene, closeCurrentPanel, hideWaiting, showPanel, showWaiting } from "../../module/ctrls";
import { RES } from "../../module/RES";
import { layers } from "../../module/views/layers";
import { Scene } from "../../module/views/Scene";
import getObject from "../common/getObject";
import getQueryParams from "../common/getQueryParams";
import Marquee from "../common/Marquee";
import Mask from "../common/Mask";
import { hideShareMask } from "../common/ShareMask";
import { PrizePanel } from "../panels/prize";
import { RulePanel } from "../panels/rule";
import { getPxTokenSave, sendWebNet, WebNetName } from "../WebNet";
import { IndexScene } from "./IndexScene";
let prize;
export class NewbieScene extends Scene {
    onPageVisibilityChange = async (visible) => {
        if (getQueryParams().disablewatch == 1) { console.log('disable watch'); return; }
        console.log('页面visible', visible);
        if (!prize) {
            console.log('没有领体验金'); return;
        };
        if (visible) {
            hideShareMask();
            closeCurrentPanel();
            changeScene(IndexScene, { from: 'NewbieScene', action: 'showSharePanel' });
        }
    }

    async start(data) {
        super.start();

        const query = getQueryParams();
        if (query.autoprize == 1) {
            this.openPrize();
        }
    }

    openPrize() {
        prize = 1;
        showWaiting();
        getPxTokenSave().then(token => {
            sendWebNet(WebNetName.acquireExperienceAmount, { token: token }).then(acquireExperienceAmount => {
                hideWaiting();

                const mask = new Mask();
                layers.topLayer.addChild(mask);
                const opensvga = new FYGE.MovieClip(RES.getRes('open.svga'));
                opensvga.mouseChildren = opensvga.mouseEnable = false;
                layers.topLayer.addChild(opensvga);
                opensvga.startAniRange(1, opensvga.totalFrames, 1, () => {
                    FYGE.Tween.get(opensvga).to({alpha:0},200).call(()=>{layers.topLayer.removeChild(opensvga);})
                });
                const func = () => {
                    if (opensvga.currentFrame == 70) {
                        opensvga.removeEventListener(FYGE.Event.ENTER_FRAME, func, this);
                        layers.topLayer.removeChild(mask);
                        if (acquireExperienceAmount.success)
                            showPanel(PrizePanel, acquireExperienceAmount.data);
                    }
                };
                opensvga.addEventListener(FYGE.Event.ENTER_FRAME, func, this);


            })
        })

    }

    onClick_openBtn() {
        FYGE.Tween.removeTweens(getObject(this,'newbie_open'))
        this.openPrize()
    }

    onClick_ruleBtn() {
        showPanel(RulePanel);
    }

    initUi() {
        super.initUi();

        const layer = new FYGE.Sprite;
        layer.mouseEnable = layer.mouseChildren = false;
        this.addChild(layer);
        

        sendWebNet(WebNetName.carouselInfo).then(res => {
            const template = '{phone}邀请了1位好友，获得了{amount}体验金';
            const datas = res.data.map(item => {
                let str = template.replace('{phone}', item.nickname);
                str = str.replace('{friend}', item.friend);
                str = str.replace('{amount}', item.amount);
                return str
            });
            const q = layer.addChild(new Marquee(datas));
            q.x = 135; q.y = 448;
            window['q'] = q;
        });

        const indexsvga = new FYGE.MovieClip(RES.getRes('index.svga'));
        indexsvga.mouseChildren = indexsvga.mouseEnable = false;
        this.addChild(indexsvga);

        this.addChild(getObject(this,'newbie_pic2'));

        const  newbie_open = getObject(this,'newbie_open');
        newbie_open.anchorX = 408/2;
        newbie_open.anchorY = 158/2;
        FYGE.Tween.get(newbie_open,{loop:true}).to({scaleX:1.1,scaleY:1.1},500).to({scaleX:1,scaleY:1},500)
    }

    initEvents() {
        super.initEvents();
        watchPageVisibility(this.onPageVisibilityChange);
        getObject(this, 'newbie_open').addEventListener(FYGE.MouseEvent.CLICK, this.onClick_openBtn, this);
        getObject(this, 'newbie_rule').addEventListener(FYGE.MouseEvent.CLICK, this.onClick_ruleBtn, this);
    }

    removeEvents() {
        super.removeEvents();
        unwatchPageVisibility(this.onPageVisibilityChange)
        getObject(this, 'newbie_open').removeEventListener(FYGE.MouseEvent.CLICK, this.onClick_openBtn, this);
        getObject(this, 'newbie_rule').removeEventListener(FYGE.MouseEvent.CLICK, this.onClick_ruleBtn, this);
    }

    get groupNames() { return ["newbie"] }
    get skinName() { return "newbie" }


}
